##  Relation Mapping Behaviour
Some settings in the relation mapping behaviour can only be configured in the advanced settings.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756a7447a441014be4192dd57c98548_LowRes.png)
